@@ -194,11 +194,54 @@ namespace Tomboy.Sync
 			}
 
 			Preferences.SettingChanged += Preferences_SettingChanged;
+			NoteMgr.NoteSaved += (n) => HandleNoteSavedOrDeleted ();
+			NoteMgr.NoteDeleted += (o, n) => HandleNoteSavedOrDeleted ();
 
 			// Update sync item based on configuration.
 			UpdateSyncAction ();
 		}
 
+		static void HandleNoteSavedOrDeleted ()
+		{
+			if (syncThread == null && autosyncTimer != null && autosyncTimeoutPrefMinutes > 0) {
+				TimeSpan timeSinceLastCheck =
+					DateTime.Now - lastBackgroundCheck;
+				TimeSpan timeUntilNextCheck =
+					new TimeSpan (0, currentAutosyncTimeoutMinutes, 0) - timeSinceLastCheck;
+				if (timeUntilNextCheck.TotalMinutes < 1) {
+					Logger.Debug ("Note saved or deleted within a minute of next autosync...resetting sync timer");
+					currentAutosyncTimeoutMinutes = 1;
+					autosyncTimer.Change (currentAutosyncTimeoutMinutes * 60000,
+					                      autosyncTimeoutPrefMinutes * 60000);
+					NoteMgr.NoteBufferChanged -= HandleNoteBufferChanged;
+					NoteMgr.NoteBufferChanged += HandleNoteBufferChanged;
+				}
+			} else if (syncThread == null && autosyncTimer == null && autosyncTimeoutPrefMinutes > 0) {
+				Logger.Debug ("Note saved or deleted...restarting sync timer");
+				lastBackgroundCheck = DateTime.Now;
+				 // Perform a sync one minute after setting change
+				currentAutosyncTimeoutMinutes = 1;
+				autosyncTimer = new Timer ((o) => BackgroundSyncChecker (),
+				                           null,
+				                           currentAutosyncTimeoutMinutes * 60000,
+				                           autosyncTimeoutPrefMinutes * 60000);
+				NoteMgr.NoteBufferChanged -= HandleNoteBufferChanged;
+				NoteMgr.NoteBufferChanged += HandleNoteBufferChanged;
+			}
+		}
+
+		static void HandleNoteBufferChanged (Note note)
+		{
+			// If note text changes, kill the timer.  It will
+			// automatically be resurrected once a Save occurs.
+			if (syncThread == null && autosyncTimer != null) {
+				Logger.Debug ("Note edited...killing autosync timer until next save or delete event");
+				autosyncTimer.Dispose ();
+				autosyncTimer = null;
+			}
+			NoteMgr.NoteBufferChanged -= HandleNoteBufferChanged;
+		}
+
 		static void Preferences_SettingChanged (object sender, EventArgs args)
 		{
 			// Update sync item based on configuration.
@@ -206,7 +249,11 @@ namespace Tomboy.Sync
 		}
 
 		private static Timer autosyncTimer;
-		private static int autosyncTimeout = -1;
+		private static int autosyncTimeoutPrefMinutes = -1;
+		// This may differ from the pref, if some logic has determined
+		// that the next background check should occur in, say, 1 minute
+		private static int currentAutosyncTimeoutMinutes = -1;
+		private static DateTime lastBackgroundCheck;
 
 		static void UpdateSyncAction ()
 		{
@@ -214,32 +261,40 @@ namespace Tomboy.Sync
 			Tomboy.ActionManager["SyncNotesAction"].Sensitive = !string.IsNullOrEmpty (sync_addin_id);
 
 			int timeoutPref = (int) Preferences.Get (Preferences.SYNC_AUTOSYNC_TIMEOUT);
-			if (timeoutPref != autosyncTimeout) {
-				autosyncTimeout = timeoutPref;
+			if (timeoutPref != autosyncTimeoutPrefMinutes) {
+				autosyncTimeoutPrefMinutes = timeoutPref;
 				if (autosyncTimer != null) {
 					autosyncTimer.Dispose ();
 					autosyncTimer = null;
 				}
-				if (autosyncTimeout > 0) {
-					autosyncTimeout = autosyncTimeout >= 5 ? autosyncTimeout : 5;
+				if (autosyncTimeoutPrefMinutes > 0) {
+					Logger.Debug ("Autosync pref changed...restarting sync timer");
+					autosyncTimeoutPrefMinutes = autosyncTimeoutPrefMinutes >= 5 ? autosyncTimeoutPrefMinutes : 5;
+					lastBackgroundCheck = DateTime.Now;
+					 // Perform a sync one minute after setting change
+					currentAutosyncTimeoutMinutes = 1;
 					autosyncTimer = new Timer ((o) => BackgroundSyncChecker (),
 					                           null,
-					                           60000, // Perform a sync one minute after setting change
-					                           autosyncTimeout * 60000);
+					                           currentAutosyncTimeoutMinutes * 60000,
+					                           autosyncTimeoutPrefMinutes * 60000);
+					NoteMgr.NoteBufferChanged -= HandleNoteBufferChanged;
+					NoteMgr.NoteBufferChanged += HandleNoteBufferChanged;
 				}
 			}
 		}
 
 		static void BackgroundSyncChecker ()
 		{
+			lastBackgroundCheck = DateTime.Now;
+			currentAutosyncTimeoutMinutes = autosyncTimeoutPrefMinutes;
 			if (syncThread != null)
 				return;
 			var addin = GetConfiguredSyncService ();
 			if (addin != null) {
 				// TODO: block sync while checking
 				var server = addin.CreateSyncServer ();
-				bool clientHasUpdates = client.DeletedNoteTitles.Count > 0;
 				bool serverHasUpdates = false;
+				bool clientHasUpdates = client.DeletedNoteTitles.Count > 0;
 				if (!clientHasUpdates) {
 					foreach (Note note in new List<Note> (NoteMgr.Notes)) {
 						if (client.GetRevision (note) == -1 ||
@@ -249,12 +304,18 @@ namespace Tomboy.Sync
 						}
 					}
 				}
-				// Wasteful to check when we'll sync anyway
-				// TODO: Unless we want to show a bubble when server has updates for users that don't autosync
-				if (!clientHasUpdates) {
-					Logger.Debug ("BackgroundSyncChecker: No client updates; checking with server");
+
+				// NOTE: Important to check, at least to verify
+				//       that server is available
+				try {
+					Logger.Debug ("BackgroundSyncChecker: Checking server for updates");
 					serverHasUpdates = server.UpdatesAvailableSince (client.LastSynchronizedRevision);
+				} catch {
+					// TODO: A libnotify bubble might be nice
+					Logger.Debug ("BackgroundSyncChecker: Error connecting to server");
+					return;
 				}
+
 				addin.PostSyncCleanup (); // Let FUSE unmount, etc
 
 				if (clientHasUpdates || serverHasUpdates) {
