@@ -344,6 +344,7 @@ namespace Tomboy
 				"\tBenjamin Podszun",
 				"\tBuchner Johannes",
 				"\tChris Scobell",
+				"\tClemens N. Buss",
 				"\tDave Foster",
 				"\tDavid Trowbridge",
 				"\tDoug Johnston",
@@ -371,8 +372,10 @@ namespace Tomboy
 				"\tMark Wakim",
 				"\tMathias Hasselmann",
 				"\tMatt Johnston",
+				"\tMatt Jones",
 				"\tMike Mazur",
 				"\tNathaniel Smith",
+				"\tOlivier Le Thanh Duong",
 				"\tPaul Cutler",
 				"\tPrzemysław Grzegorczyk",
 				"\tRobert Buchholz",
